﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UBotPlugin;
using System.Diagnostics;

namespace BrowserReplacementCommands
{
    /// <summary>
    /// This command is an example of a command that can be generated from a user interface. 
    /// It will show a picture if given a filename of a picture.
    /// Parameters: The file to open.
    /// </summary>
    public class DisplayPictureCommand : IUBotCommand
    {
        // List to hold the parameters we define for our command.
        private List<UBotParameterDefinition> _parameters = new List<UBotParameterDefinition>();

        public DisplayPictureCommand()
        {
            // Add our parameter (File) with a String type since it is text.
            _parameters.Add(new UBotParameterDefinition("File", UBotType.String));
        }

        public string Category
        {
            // This is what category our command is categorized as. 
            // If you choose something not already in the toolbox list, a new category will be created.
            get { return "Action Commands"; }
        }

        public string CommandName
        {
            // The name of our node in UBot Studio.
            get { return "display picture"; }
        }

        public void Execute(IUBotStudio ubotStudio, Dictionary<string, string> parameters)
        {
            // Grab the value of the File parameter we defined.
            string file = parameters["File"];

            // Open the picture in windows photo viewer.
            Process.Start(file);
        }

        public bool IsContainer
        {
            // This command does not have any nested commands inside of it, so it is not a container command.
            get { return false; }
        }

        public IEnumerable<UBotParameterDefinition> ParameterDefinitions
        {
            // We reference our parameter list we defined above here.
            get { return _parameters; }
        }

        public UBotVersion UBotVersion
        {
            get { return UBotVersion.Standard; }
        }
    }
}
