﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Win32;
using System.IO;
using UBotPlugin;

namespace BrowserReplacementCommands
{
    /// <summary>
    /// Interaction logic for PictureChooser.xaml
    /// </summary>
    public partial class PictureChooser : UserControl
    {
        public IUserInterfaceCallback Callback;

        public PictureChooser()
        {
            InitializeComponent();
        }

        private void BrowseButtonClick(object sender, RoutedEventArgs e)
        {
            var dialog = new System.Windows.Forms.FolderBrowserDialog();

            // Display a folder browser when the Browse button is clicked.
            var result = dialog.ShowDialog();
            if (result == System.Windows.Forms.DialogResult.OK)
            {
                // Clear out any old images in the panel.
                ImagesWrapPanel.Children.Clear();

                var directory = dialog.SelectedPath;
                DirectoryTextBox.Text = directory;

                // Get all png, jpg and gif files in the chosen directory
                var files = Directory.GetFiles(directory, "*.png").
                    Concat(Directory.GetFiles(directory, "*.jpg")).
                    Concat(Directory.GetFiles(directory, "*.gif"));

                // For each of the files, create an Image object and add it to the panel.
                foreach (var file in files)
                {
                    var bitmapImage = new BitmapImage();
                    bitmapImage.BeginInit();
                    bitmapImage.UriSource = new Uri(file);
                    bitmapImage.EndInit();

                    var image = new Image();
                    image.Width = 100;
                    image.Height = 100;
                    image.Margin = new Thickness(5);
                    image.Source = bitmapImage;
                    image.Tag = file;
                    ImagesWrapPanel.Children.Add(image);
                    
                    // When a user mouses down on an image, we want to call ImageMouseDown.
                    image.MouseDown += ImageMouseDown;
                }
            }
        }

        private void ImageMouseDown(object sender, MouseButtonEventArgs e)
        {
            var imageSender = (Image)sender;

            // Create a command for dragging, so we can drag a picture to the node view and create a display picture command.
            var command = new DisplayPictureCommand();
            // We stored the file name in the tag of the image, so we access that and set it to the default value of our new command to prefill the input.
            command.ParameterDefinitions.First().DefaultValue = imageSender.Tag;

            // Tell UBot Studio that we are dragging this command.
            Callback.StartDrag(command);
        }
    }
}
