﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UBotPlugin;
using System.Net;

namespace SimpleCommands
{
    /// <summary>
    /// This command is an example of a command with a table parameter.
    /// It will download the response headers from a URL and store them in a table.
    /// Parameters: The URL to download the headers from.
    /// </summary>
    public class CreateTableFromHeadersCommand : IUBotCommand
    {
        // List to hold the parameters we define for our command.
        private List<UBotParameterDefinition> _parameters = new List<UBotParameterDefinition>();

        public CreateTableFromHeadersCommand()
        {
            // Add our parameter (URL) with a String type since it is text.
            _parameters.Add(new UBotParameterDefinition("URL", UBotType.String));

            // Add our parameter (Table) with a UBotTable type since it is a table.
            _parameters.Add(new UBotParameterDefinition("Table", UBotType.UBotTable));
        }

        public string Category
        {
            // This is what category our command is categorized as. 
            // If you choose something not already in the toolbox list, a new category will be created.
            get { return "Browser Commands"; }
        }

        public string CommandName
        {
            // The name of our node in UBot Studio.
            get { return "create table from headers"; }
        }

        public void Execute(IUBotStudio ubotStudio, Dictionary<string, string> parameters)
        {
            // Grab the value of the parameter we defined.
            string url = parameters["URL"];

            // Get the name of the table they are using.
            string tableName = parameters["Table"];

            // Create an HttpWebRequest for the specified URL. 
            HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);

            // Set method to HEAD since we only want the headers.
            request.Method = "HEAD";

            // Send the HttpWebRequest and wait for the response, closing it when done.
            using (HttpWebResponse response = (HttpWebResponse)request.GetResponse())
            {
                // Create a table to store the headers returned.
                string[,] table = new string[response.Headers.Count, 2];

                for (int i = 0; i < response.Headers.Count; i++)
                {
                    // Store the header name in column 0 for the current row.
                    table[i, 0] = response.Headers.Keys[i];
                    // Store the header value in column 1 for the current row.
                    table[i, 1] = response.Headers[i];
                }

                // Set the new table in UBot Studio for the table name given.
                ubotStudio.SetTable(tableName, table);
            }
        }

        public bool IsContainer
        {
            // This command does not have any nested commands inside of it, so it is not a container command.
            get { return false; }
        }

        public IEnumerable<UBotParameterDefinition> ParameterDefinitions
        {
            // We reference our parameter list we defined above here.
            get { return _parameters; }
        }

        public UBotVersion UBotVersion
        {
            get { return UBotVersion.Standard; }
        }
    }
}
