﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UBotPlugin;

namespace SimpleCommands
{
    /// <summary>
    /// This command is an example of a command using list parameters.
    /// It shuffles the input list sent to it..
    /// Parameters: The hexadecimal color to use to display the window.
    /// </summary>
    public class ShuffleListFunction : IUBotFunction
    {
        // List to hold the parameters we define for our command.
        private List<UBotParameterDefinition> _parameters = new List<UBotParameterDefinition>();
        private List<string> _returnValue;

        public ShuffleListFunction()
        {
            // Add our parameter (List To Shuffle) with a UBotList type since it is a list.
            _parameters.Add(new UBotParameterDefinition("List To Shuffle", UBotType.UBotList));
        }

        public string Category
        {
            // This is what category our command is categorized as. 
            // If you choose something not already in the toolbox list, a new category will be created.
            get { return "Variable Functions"; }
        }

        public string FunctionName
        {
            // The name of our node in UBot Studio.
            // You need to use a $ sign in front of function names.
            get { return "$shuffle list"; }
        }

        public void Execute(IUBotStudio ubotStudio, Dictionary<string, string> parameters)
        {
            // Get the name of the list they are using.
            var listName = parameters["List To Shuffle"];

            // Get the list items from the list by using the list variable name.
            var list = ubotStudio.GetList(listName);

            // Shuffle the list
            var randomGenerator = new Random();
            list = list.OrderBy(x => randomGenerator.Next()).ToList();

            // Set the return value to the shuffled list.
            _returnValue = list;
        }

        public bool IsContainer
        {
            // This command does not have any nested commands inside of it, so it is not a container command.
            get { return false; }
        }

        public IEnumerable<UBotParameterDefinition> ParameterDefinitions
        {
            // We reference our parameter list we defined above here.
            get { return _parameters; }
        }

        public object ReturnValue
        {
            // We return our variable _returnValue as the result of the function.
            get { return _returnValue; }
        }

        public UBotType ReturnValueType
        {
            // Our result is a list, so the return value type is UBotList.
            get { return UBotType.UBotList; }
        }

        public UBotVersion UBotVersion
        {
            get { return UBotVersion.Standard; }
        }
    }       
}