﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UBotPlugin;
using System.Windows.Media;
using System.Windows;
using System.Windows.Threading;

namespace WizardCommands
{
    /// <summary>
    /// This command is an example of a command with a wizard.
    /// It will show a window with a background color that you choose.
    /// Parameters: The hexadecimal color to use to display the window.
    /// </summary>
    public class ColoredWindowCommand : IUBotCommand, IWizardEnabled
    {
        // List to hold the parameters we define for our command.
        private List<UBotParameterDefinition> _parameters = new List<UBotParameterDefinition>();
        
        // This holds our wizard Window.
        private ColorPickerWizardWindow _wizardWindow;

        public ColoredWindowCommand()
        {
            // Add our parameter (Color) with a String type since it is text.
            _parameters.Add(new UBotParameterDefinition("Color", UBotType.String));
        }

        public string Category
        {
            // This is what category our command is categorized as. 
            // If you choose something not already in the toolbox list, a new category will be created.
            get { return "Flow Commands"; }
        }

        public string CommandName
        {
            // The name of our node in UBot Studio.
            get { return "colored window"; }
        }

        public void Execute(IUBotStudio ubotStudio, Dictionary<string, string> parameters)
        {
            // Grab the value of the Color parameter we defined.
            string value = parameters["Color"];

            // Create a colored window and set the background color to the color they choose.
            var window = new ColoredWindow();
            window.Background = new SolidColorBrush((Color)ColorConverter.ConvertFromString("#" + value));

            // Display the colored window.
            window.ShowDialog();
        }

        public bool IsContainer
        {
            // This command does not have any nested commands inside of it, so it is not a container command.
            get { return false; }
        }

        public IEnumerable<UBotParameterDefinition> ParameterDefinitions
        {
            // We reference our parameter list we defined above here.
            get { return _parameters; }
        }

        public IWizard GenerateWizard()
        {
            return new ColoredWindowWizard();
        }

        public UBotVersion UBotVersion
        {
            get { return UBotVersion.Standard; }
        }
    }

    /// <summary>
    /// This wizard contains a color picker control that allows a user to choose a color by clicking it.
    /// </summary>
    public class ColoredWindowWizard : IWizard
    {
        private ColorPickerWizardWindow _wizardWindow = new ColorPickerWizardWindow();

        public Dictionary<string, string> WizardValues
        {
            // This property is checked after the wizard is displayed.
            // We return a Dictionary of values corresponding to the parameters.
            get
            {
                var parameterValues = new Dictionary<string, string>();
                // We use our _wizardWindow reference to access the color they selected in the wizard.
                // We then add that color value to our list of parameter values from our wizard.
                parameterValues["Color"] = _wizardWindow.MainColorPicker.SelectedColor.ToString().Substring(1);
                return parameterValues;
            }
        }

        public Window WizardWindow
        {
            // This property is accessed to determine which window to display for the wizard.
            get
            {
                return _wizardWindow;
            }
        }
    }
}
